@@ -1,8 +1,8 @@
 """Consolidated and cleaned AST for Synapse language."""
 
 from dataclasses import dataclass
-from typing import Any, List, Optional, Dict, Union
 from enum import Enum, auto
+from typing import Optional
 
 
 class NodeType(Enum):
@@ -12,47 +12,47 @@ class NodeType(Enum):
     STRING = auto()
     IDENTIFIER = auto()
     UNCERTAIN = auto()
-    
+
     # Operations
     BINARY_OP = auto()
     UNARY_OP = auto()
     ASSIGNMENT = auto()
     FUNCTION_CALL = auto()
-    
+
     # Collections
     LIST = auto()
     MATRIX = auto()
     TENSOR = auto()
-    
+
     # Scientific constructs
     HYPOTHESIS = auto()
     EXPERIMENT = auto()
     PARALLEL = auto()
     BRANCH = auto()
     STREAM = auto()
-    
+
     # Reasoning
     REASON_CHAIN = auto()
     PREMISE = auto()
     DERIVE = auto()
     CONCLUDE = auto()
-    
+
     # Pipeline
     PIPELINE = auto()
     STAGE = auto()
-    
+
     # Exploration
     EXPLORE = auto()
     TRY = auto()
     FALLBACK = auto()
-    
+
     # Uncertainty
     PROPAGATE = auto()
-    
+
     # Symbolic
     PROVE = auto()
     SYMBOLIC = auto()
-    
+
     # Quantum
     QUANTUM_CIRCUIT = auto()
     QUANTUM_GATE = auto()
@@ -61,19 +61,19 @@ class NodeType(Enum):
     QUANTUM_ALGORITHM = auto()
     QUANTUM_ANSATZ = auto()
     RUN = auto()
-    
+
     # Control flow
     BLOCK = auto()
     PROGRAM = auto()
     IF = auto()
     WHILE = auto()
     FOR = auto()
-    
+
     # Constraints
     CONSTRAINT = auto()
     EVOLVE = auto()
     OBSERVE = auto()
-    
+
     # Channels
     CHANNEL = auto()
     ASYNC = auto()
@@ -86,10 +86,10 @@ class ASTNode:
     node_type: NodeType
     line: int
     column: int
-    
+
     def accept(self, visitor):
         """Visitor pattern support."""
-        method_name = f'visit_{self.__class__.__name__}'
+        method_name = f"visit_{self.__class__.__name__}"
         visitor_method = getattr(visitor, method_name, visitor.generic_visit)
         return visitor_method(self)
 
@@ -99,7 +99,7 @@ class ASTNode:
 class NumberNode(ASTNode):
     """Numeric literal."""
     value: float
-    
+
     def __init__(self, value: float, line: int, column: int):
         super().__init__(NodeType.NUMBER, line, column)
         self.value = value
@@ -109,7 +109,7 @@ class NumberNode(ASTNode):
 class StringNode(ASTNode):
     """String literal."""
     value: str
-    
+
     def __init__(self, value: str, line: int, column: int):
         super().__init__(NodeType.STRING, line, column)
         self.value = value
@@ -119,7 +119,7 @@ class StringNode(ASTNode):
 class IdentifierNode(ASTNode):
     """Identifier/variable reference."""
     name: str
-    
+
     def __init__(self, name: str, line: int, column: int):
         super().__init__(NodeType.IDENTIFIER, line, column)
         self.name = name
@@ -130,10 +130,10 @@ class UncertainNode(ASTNode):
     """Uncertain value with error bounds."""
     value: float
     uncertainty: float
-    distribution: Optional[str] = None
-    
+    distribution: str | None = None
+
     def __init__(self, value: float, uncertainty: float, line: int, column: int,
-                 distribution: Optional[str] = None):
+                 distribution: str | None = None):
         super().__init__(NodeType.UNCERTAIN, line, column)
         self.value = value
         self.uncertainty = uncertainty
@@ -144,9 +144,9 @@ class UncertainNode(ASTNode):
 @dataclass
 class ListNode(ASTNode):
     """List literal."""
-    elements: List[ASTNode]
-    
-    def __init__(self, elements: List[ASTNode], line: int, column: int):
+    elements: list[ASTNode]
+
+    def __init__(self, elements: list[ASTNode], line: int, column: int):
         super().__init__(NodeType.LIST, line, column)
         self.elements = elements
 
@@ -154,9 +154,9 @@ class ListNode(ASTNode):
 @dataclass
 class MatrixNode(ASTNode):
     """Matrix literal."""
-    rows: List[List[ASTNode]]
-    
-    def __init__(self, rows: List[List[ASTNode]], line: int, column: int):
+    rows: list[list[ASTNode]]
+
+    def __init__(self, rows: list[list[ASTNode]], line: int, column: int):
         super().__init__(NodeType.MATRIX, line, column)
         self.rows = rows
 
@@ -165,11 +165,11 @@ class MatrixNode(ASTNode):
 class TensorNode(ASTNode):
     """Tensor declaration."""
     name: str
-    dimensions: List[int]
-    initializer: Optional[ASTNode] = None
-    
-    def __init__(self, name: str, dimensions: List[int], line: int, column: int,
-                 initializer: Optional[ASTNode] = None):
+    dimensions: list[int]
+    initializer: ASTNode | None = None
+
+    def __init__(self, name: str, dimensions: list[int], line: int, column: int,
+                 initializer: ASTNode | None = None):
         super().__init__(NodeType.TENSOR, line, column)
         self.name = name
         self.dimensions = dimensions
@@ -182,10 +182,10 @@ class BinaryOpNode(ASTNode):
     """Binary operation."""
     operator: str
     left: ASTNode
-    right: Union[ASTNode, List[ASTNode]]  # List for ternary operator
-    
-    def __init__(self, operator: str, left: ASTNode, 
-                 right: Union[ASTNode, List[ASTNode]], line: int, column: int):
+    right: ASTNode | list[ASTNode]  # List for ternary operator
+
+    def __init__(self, operator: str, left: ASTNode,
+                 right: ASTNode | list[ASTNode], line: int, column: int):
         super().__init__(NodeType.BINARY_OP, line, column)
         self.operator = operator
         self.left = left
@@ -197,7 +197,7 @@ class UnaryOpNode(ASTNode):
     """Unary operation."""
     operator: str
     operand: ASTNode
-    
+
     def __init__(self, operator: str, operand: ASTNode, line: int, column: int):
         super().__init__(NodeType.UNARY_OP, line, column)
         self.operator = operator
@@ -207,13 +207,13 @@ class UnaryOpNode(ASTNode):
 @dataclass
 class AssignmentNode(ASTNode):
     """Variable assignment."""
-    target: Union[str, IdentifierNode]
+    target: str | IdentifierNode
     value: ASTNode
     is_uncertain: bool = False
     is_constrained: bool = False
     is_evolving: bool = False
-    
-    def __init__(self, target: Union[str, IdentifierNode], value: ASTNode,
+
+    def __init__(self, target: str | IdentifierNode, value: ASTNode,
                  line: int, column: int, is_uncertain: bool = False,
                  is_constrained: bool = False, is_evolving: bool = False):
         super().__init__(NodeType.ASSIGNMENT, line, column)
@@ -227,10 +227,10 @@ class AssignmentNode(ASTNode):
 @dataclass
 class FunctionCallNode(ASTNode):
     """Function call."""
-    function: Union[str, ASTNode]
-    arguments: List[ASTNode]
-    
-    def __init__(self, function: Union[str, ASTNode], arguments: List[ASTNode],
+    function: str | ASTNode
+    arguments: list[ASTNode]
+
+    def __init__(self, function: str | ASTNode, arguments: list[ASTNode],
                  line: int, column: int):
         super().__init__(NodeType.FUNCTION_CALL, line, column)
         self.function = function
@@ -242,12 +242,12 @@ class FunctionCallNode(ASTNode):
 class HypothesisNode(ASTNode):
     """Hypothesis with assumptions, predictions, and validation."""
     name: str
-    assumptions: List[ASTNode]
-    predictions: List[ASTNode]
-    validations: List[ASTNode]
-    
-    def __init__(self, name: str, assumptions: List[ASTNode],
-                 predictions: List[ASTNode], validations: List[ASTNode],
+    assumptions: list[ASTNode]
+    predictions: list[ASTNode]
+    validations: list[ASTNode]
+
+    def __init__(self, name: str, assumptions: list[ASTNode],
+                 predictions: list[ASTNode], validations: list[ASTNode],
                  line: int, column: int):
         super().__init__(NodeType.HYPOTHESIS, line, column)
         self.name = name
@@ -260,12 +260,12 @@ class HypothesisNode(ASTNode):
 class ExperimentNode(ASTNode):
     """Experiment with setup, procedure, and synthesis."""
     name: str
-    setup: Optional[ASTNode]
-    branches: List['BranchNode']
-    synthesize: Optional[ASTNode]
-    
-    def __init__(self, name: str, setup: Optional[ASTNode],
-                 branches: List['BranchNode'], synthesize: Optional[ASTNode],
+    setup: ASTNode | None
+    branches: list["BranchNode"]
+    synthesize: ASTNode | None
+
+    def __init__(self, name: str, setup: ASTNode | None,
+                 branches: list["BranchNode"], synthesize: ASTNode | None,
                  line: int, column: int):
         super().__init__(NodeType.EXPERIMENT, line, column)
         self.name = name
@@ -277,11 +277,11 @@ class ExperimentNode(ASTNode):
 @dataclass
 class ParallelNode(ASTNode):
     """Parallel execution block."""
-    branches: List['BranchNode']
-    num_workers: Optional[int] = None
-    
-    def __init__(self, branches: List['BranchNode'], line: int, column: int,
-                 num_workers: Optional[int] = None):
+    branches: list["BranchNode"]
+    num_workers: int | None = None
+
+    def __init__(self, branches: list["BranchNode"], line: int, column: int,
+                 num_workers: int | None = None):
         super().__init__(NodeType.PARALLEL, line, column)
         self.branches = branches
         self.num_workers = num_workers
@@ -291,9 +291,9 @@ class ParallelNode(ASTNode):
 class BranchNode(ASTNode):
     """Execution branch."""
     name: str
-    body: Union[ASTNode, List[ASTNode]]
-    
-    def __init__(self, name: str, body: Union[ASTNode, List[ASTNode]],
+    body: ASTNode | list[ASTNode]
+
+    def __init__(self, name: str, body: ASTNode | list[ASTNode],
                  line: int, column: int):
         super().__init__(NodeType.BRANCH, line, column)
         self.name = name
@@ -305,7 +305,7 @@ class StreamNode(ASTNode):
     """Thought stream for parallel processing."""
     name: str
     expression: ASTNode
-    
+
     def __init__(self, name: str, expression: ASTNode, line: int, column: int):
         super().__init__(NodeType.STREAM, line, column)
         self.name = name
@@ -317,12 +317,12 @@ class StreamNode(ASTNode):
 class ReasonChainNode(ASTNode):
     """Reasoning chain with premises and conclusions."""
     name: str
-    premises: List['PremiseNode']
-    derivations: List['DeriveNode']
-    conclusions: List['ConcludeNode']
-    
-    def __init__(self, name: str, premises: List['PremiseNode'],
-                 derivations: List['DeriveNode'], conclusions: List['ConcludeNode'],
+    premises: list["PremiseNode"]
+    derivations: list["DeriveNode"]
+    conclusions: list["ConcludeNode"]
+
+    def __init__(self, name: str, premises: list["PremiseNode"],
+                 derivations: list["DeriveNode"], conclusions: list["ConcludeNode"],
                  line: int, column: int):
         super().__init__(NodeType.REASON_CHAIN, line, column)
         self.name = name
@@ -336,7 +336,7 @@ class PremiseNode(ASTNode):
     """Logical premise."""
     name: str
     statement: str
-    
+
     def __init__(self, name: str, statement: str, line: int, column: int):
         super().__init__(NodeType.PREMISE, line, column)
         self.name = name
@@ -349,7 +349,7 @@ class DeriveNode(ASTNode):
     name: str
     from_premise: str
     statement: str
-    
+
     def __init__(self, name: str, from_premise: str, statement: str,
                  line: int, column: int):
         super().__init__(NodeType.DERIVE, line, column)
@@ -362,7 +362,7 @@ class DeriveNode(ASTNode):
 class ConcludeNode(ASTNode):
     """Conclusion from reasoning."""
     expression: ASTNode
-    
+
     def __init__(self, expression: ASTNode, line: int, column: int):
         super().__init__(NodeType.CONCLUDE, line, column)
         self.expression = expression
@@ -373,9 +373,9 @@ class ConcludeNode(ASTNode):
 class PipelineNode(ASTNode):
     """Data processing pipeline."""
     name: str
-    stages: List['StageNode']
-    
-    def __init__(self, name: str, stages: List['StageNode'], line: int, column: int):
+    stages: list["StageNode"]
+
+    def __init__(self, name: str, stages: list["StageNode"], line: int, column: int):
         super().__init__(NodeType.PIPELINE, line, column)
         self.name = name
         self.stages = stages
@@ -385,13 +385,13 @@ class PipelineNode(ASTNode):
 class StageNode(ASTNode):
     """Pipeline stage."""
     name: str
-    parallelism: Optional[int]
-    operations: Dict[str, ASTNode]
-    fork_paths: Optional[Dict[str, ASTNode]] = None
-    
-    def __init__(self, name: str, parallelism: Optional[int],
-                 operations: Dict[str, ASTNode], line: int, column: int,
-                 fork_paths: Optional[Dict[str, ASTNode]] = None):
+    parallelism: int | None
+    operations: dict[str, ASTNode]
+    fork_paths: dict[str, ASTNode] | None = None
+
+    def __init__(self, name: str, parallelism: int | None,
+                 operations: dict[str, ASTNode], line: int, column: int,
+                 fork_paths: dict[str, ASTNode] | None = None):
         super().__init__(NodeType.STAGE, line, column)
         self.name = name
         self.parallelism = parallelism
@@ -404,15 +404,15 @@ class StageNode(ASTNode):
 class ExploreNode(ASTNode):
     """Solution space exploration."""
     name: str
-    try_paths: List['TryNode']
-    fallback_paths: List['FallbackNode']
-    accept_condition: Optional[ASTNode]
-    reject_condition: Optional[ASTNode]
-    
-    def __init__(self, name: str, try_paths: List['TryNode'],
-                 fallback_paths: List['FallbackNode'],
-                 accept_condition: Optional[ASTNode],
-                 reject_condition: Optional[ASTNode],
+    try_paths: list["TryNode"]
+    fallback_paths: list["FallbackNode"]
+    accept_condition: ASTNode | None
+    reject_condition: ASTNode | None
+
+    def __init__(self, name: str, try_paths: list["TryNode"],
+                 fallback_paths: list["FallbackNode"],
+                 accept_condition: ASTNode | None,
+                 reject_condition: ASTNode | None,
                  line: int, column: int):
         super().__init__(NodeType.EXPLORE, line, column)
         self.name = name
@@ -427,7 +427,7 @@ class TryNode(ASTNode):
     """Try path in exploration."""
     name: str
     expression: ASTNode
-    
+
     def __init__(self, name: str, expression: ASTNode, line: int, column: int):
         super().__init__(NodeType.TRY, line, column)
         self.name = name
@@ -439,7 +439,7 @@ class FallbackNode(ASTNode):
     """Fallback path in exploration."""
     name: str
     expression: ASTNode
-    
+
     def __init__(self, name: str, expression: ASTNode, line: int, column: int):
         super().__init__(NodeType.FALLBACK, line, column)
         self.name = name
@@ -450,10 +450,10 @@ class FallbackNode(ASTNode):
 @dataclass
 class PropagateNode(ASTNode):
     """Uncertainty propagation."""
-    uncertainty_vars: List[str]
-    body: List[ASTNode]
-    
-    def __init__(self, uncertainty_vars: List[str], body: List[ASTNode],
+    uncertainty_vars: list[str]
+    body: list[ASTNode]
+
+    def __init__(self, uncertainty_vars: list[str], body: list[ASTNode],
                  line: int, column: int):
         super().__init__(NodeType.PROPAGATE, line, column)
         self.uncertainty_vars = uncertainty_vars
@@ -464,10 +464,10 @@ class PropagateNode(ASTNode):
 @dataclass
 class SymbolicNode(ASTNode):
     """Symbolic mathematics block."""
-    declarations: List[ASTNode]
-    operations: List[ASTNode]
-    
-    def __init__(self, declarations: List[ASTNode], operations: List[ASTNode],
+    declarations: list[ASTNode]
+    operations: list[ASTNode]
+
+    def __init__(self, declarations: list[ASTNode], operations: list[ASTNode],
                  line: int, column: int):
         super().__init__(NodeType.SYMBOLIC, line, column)
         self.declarations = declarations
@@ -478,10 +478,10 @@ class SymbolicNode(ASTNode):
 class ProveNode(ASTNode):
     """Mathematical proof."""
     statement: ASTNode
-    proof: Optional[ASTNode] = None
-    
+    proof: ASTNode | None = None
+
     def __init__(self, statement: ASTNode, line: int, column: int,
-                 proof: Optional[ASTNode] = None):
+                 proof: ASTNode | None = None):
         super().__init__(NodeType.PROVE, line, column)
         self.statement = statement
         self.proof = proof
@@ -493,11 +493,11 @@ class QuantumCircuitNode(ASTNode):
     """Quantum circuit definition."""
     name: str
     qubits: int
-    gates: List['QuantumGateNode']
-    measurements: List['QuantumMeasureNode']
-    
-    def __init__(self, name: str, qubits: int, gates: List['QuantumGateNode'],
-                 measurements: List['QuantumMeasureNode'], line: int, column: int):
+    gates: list["QuantumGateNode"]
+    measurements: list["QuantumMeasureNode"]
+
+    def __init__(self, name: str, qubits: int, gates: list["QuantumGateNode"],
+                 measurements: list["QuantumMeasureNode"], line: int, column: int):
         super().__init__(NodeType.QUANTUM_CIRCUIT, line, column)
         self.name = name
         self.qubits = qubits
@@ -509,11 +509,11 @@ class QuantumCircuitNode(ASTNode):
 class QuantumGateNode(ASTNode):
     """Quantum gate application."""
     gate_type: str
-    qubits: List[ASTNode]
-    parameters: List[ASTNode]
-    
-    def __init__(self, gate_type: str, qubits: List[ASTNode],
-                 parameters: List[ASTNode], line: int, column: int):
+    qubits: list[ASTNode]
+    parameters: list[ASTNode]
+
+    def __init__(self, gate_type: str, qubits: list[ASTNode],
+                 parameters: list[ASTNode], line: int, column: int):
         super().__init__(NodeType.QUANTUM_GATE, line, column)
         self.gate_type = gate_type
         self.qubits = qubits
@@ -523,10 +523,10 @@ class QuantumGateNode(ASTNode):
 @dataclass
 class QuantumMeasureNode(ASTNode):
     """Quantum measurement."""
-    qubits: List[ASTNode]
-    classical_bits: List[ASTNode]
-    
-    def __init__(self, qubits: List[ASTNode], classical_bits: List[ASTNode],
+    qubits: list[ASTNode]
+    classical_bits: list[ASTNode]
+
+    def __init__(self, qubits: list[ASTNode], classical_bits: list[ASTNode],
                  line: int, column: int):
         super().__init__(NodeType.QUANTUM_MEASURE, line, column)
         self.qubits = qubits
@@ -537,9 +537,9 @@ class QuantumMeasureNode(ASTNode):
 class QuantumBackendNode(ASTNode):
     """Quantum backend configuration."""
     name: str
-    config: Dict[str, ASTNode]
-    
-    def __init__(self, name: str, config: Dict[str, ASTNode], line: int, column: int):
+    config: dict[str, ASTNode]
+
+    def __init__(self, name: str, config: dict[str, ASTNode], line: int, column: int):
         super().__init__(NodeType.QUANTUM_BACKEND, line, column)
         self.name = name
         self.config = config
@@ -549,15 +549,15 @@ class QuantumBackendNode(ASTNode):
 class QuantumAlgorithmNode(ASTNode):
     """Quantum algorithm definition."""
     name: str
-    parameters: List[ASTNode]
-    ansatz: Optional['QuantumAnsatzNode']
-    cost_function: Optional[ASTNode]
-    optimizer: Optional[str]
-    
-    def __init__(self, name: str, parameters: List[ASTNode],
-                 ansatz: Optional['QuantumAnsatzNode'],
-                 cost_function: Optional[ASTNode],
-                 optimizer: Optional[str], line: int, column: int):
+    parameters: list[ASTNode]
+    ansatz: Optional["QuantumAnsatzNode"]
+    cost_function: ASTNode | None
+    optimizer: str | None
+
+    def __init__(self, name: str, parameters: list[ASTNode],
+                 ansatz: Optional["QuantumAnsatzNode"],
+                 cost_function: ASTNode | None,
+                 optimizer: str | None, line: int, column: int):
         super().__init__(NodeType.QUANTUM_ALGORITHM, line, column)
         self.name = name
         self.parameters = parameters
@@ -570,9 +570,9 @@ class QuantumAlgorithmNode(ASTNode):
 class QuantumAnsatzNode(ASTNode):
     """Quantum ansatz definition."""
     name: str
-    layers: List[ASTNode]
-    
-    def __init__(self, name: str, layers: List[ASTNode], line: int, column: int):
+    layers: list[ASTNode]
+
+    def __init__(self, name: str, layers: list[ASTNode], line: int, column: int):
         super().__init__(NodeType.QUANTUM_ANSATZ, line, column)
         self.name = name
         self.layers = layers
@@ -582,11 +582,11 @@ class QuantumAnsatzNode(ASTNode):
 class RunNode(ASTNode):
     """Circuit/algorithm execution."""
     circuit: str
-    backend: Optional[str]
-    options: Dict[str, ASTNode]
-    
-    def __init__(self, circuit: str, backend: Optional[str],
-                 options: Dict[str, ASTNode], line: int, column: int):
+    backend: str | None
+    options: dict[str, ASTNode]
+
+    def __init__(self, circuit: str, backend: str | None,
+                 options: dict[str, ASTNode], line: int, column: int):
         super().__init__(NodeType.RUN, line, column)
         self.circuit = circuit
         self.backend = backend
@@ -597,9 +597,9 @@ class RunNode(ASTNode):
 @dataclass
 class BlockNode(ASTNode):
     """Block of statements."""
-    statements: List[ASTNode]
-    
-    def __init__(self, statements: List[ASTNode], line: int, column: int):
+    statements: list[ASTNode]
+
+    def __init__(self, statements: list[ASTNode], line: int, column: int):
         super().__init__(NodeType.BLOCK, line, column)
         self.statements = statements
 
@@ -607,9 +607,9 @@ class BlockNode(ASTNode):
 @dataclass
 class ProgramNode(ASTNode):
     """Root program node."""
-    statements: List[ASTNode]
-    
-    def __init__(self, statements: List[ASTNode]):
+    statements: list[ASTNode]
+
+    def __init__(self, statements: list[ASTNode]):
         super().__init__(NodeType.PROGRAM, 0, 0)
         self.statements = statements
 
@@ -619,10 +619,10 @@ class IfNode(ASTNode):
     """Conditional statement."""
     condition: ASTNode
     then_branch: ASTNode
-    else_branch: Optional[ASTNode] = None
-    
+    else_branch: ASTNode | None = None
+
     def __init__(self, condition: ASTNode, then_branch: ASTNode,
-                 line: int, column: int, else_branch: Optional[ASTNode] = None):
+                 line: int, column: int, else_branch: ASTNode | None = None):
         super().__init__(NodeType.IF, line, column)
         self.condition = condition
         self.then_branch = then_branch
@@ -634,7 +634,7 @@ class WhileNode(ASTNode):
     """While loop."""
     condition: ASTNode
     body: ASTNode
-    
+
     def __init__(self, condition: ASTNode, body: ASTNode, line: int, column: int):
         super().__init__(NodeType.WHILE, line, column)
         self.condition = condition
@@ -647,7 +647,7 @@ class ForNode(ASTNode):
     variable: str
     iterable: ASTNode
     body: ASTNode
-    
+
     def __init__(self, variable: str, iterable: ASTNode, body: ASTNode,
                  line: int, column: int):
         super().__init__(NodeType.FOR, line, column)
@@ -662,9 +662,9 @@ class ConstraintNode(ASTNode):
     """Variable constraint."""
     variable: str
     var_type: str
-    constraints: List[ASTNode]
-    
-    def __init__(self, variable: str, var_type: str, constraints: List[ASTNode],
+    constraints: list[ASTNode]
+
+    def __init__(self, variable: str, var_type: str, constraints: list[ASTNode],
                  line: int, column: int):
         super().__init__(NodeType.CONSTRAINT, line, column)
         self.variable = variable
@@ -677,10 +677,10 @@ class EvolveNode(ASTNode):
     """Evolving variable."""
     variable: str
     initial: ASTNode
-    evolution_rule: Optional[ASTNode] = None
-    
+    evolution_rule: ASTNode | None = None
+
     def __init__(self, variable: str, initial: ASTNode, line: int, column: int,
-                 evolution_rule: Optional[ASTNode] = None):
+                 evolution_rule: ASTNode | None = None):
         super().__init__(NodeType.EVOLVE, line, column)
         self.variable = variable
         self.initial = initial
@@ -692,10 +692,10 @@ class ObserveNode(ASTNode):
     """Quantum observation."""
     variable: str
     quantum_state: ASTNode
-    collapse_condition: Optional[ASTNode] = None
-    
+    collapse_condition: ASTNode | None = None
+
     def __init__(self, variable: str, quantum_state: ASTNode, line: int, column: int,
-                 collapse_condition: Optional[ASTNode] = None):
+                 collapse_condition: ASTNode | None = None):
         super().__init__(NodeType.OBSERVE, line, column)
         self.variable = variable
         self.quantum_state = quantum_state
@@ -708,7 +708,7 @@ class ChannelNode(ASTNode):
     """Message passing channel."""
     name: str
     data_type: str
-    
+
     def __init__(self, name: str, data_type: str, line: int, column: int):
         super().__init__(NodeType.CHANNEL, line, column)
         self.name = name
@@ -719,11 +719,11 @@ class ChannelNode(ASTNode):
 class AsyncNode(ASTNode):
     """Async execution block."""
     name: str
-    body: List[ASTNode]
-    parallel_count: Optional[int] = None
-    
-    def __init__(self, name: str, body: List[ASTNode], line: int, column: int,
-                 parallel_count: Optional[int] = None):
+    body: list[ASTNode]
+    parallel_count: int | None = None
+
+    def __init__(self, name: str, body: list[ASTNode], line: int, column: int,
+                 parallel_count: int | None = None):
         super().__init__(NodeType.ASYNC, line, column)
         self.name = name
         self.body = body
@@ -733,15 +733,15 @@ class AsyncNode(ASTNode):
 @dataclass
 class SynchronizeNode(ASTNode):
     """Synchronization point."""
-    streams: List[str]
-    condition: Optional[ASTNode] = None
-    
-    def __init__(self, streams: List[str], line: int, column: int,
-                 condition: Optional[ASTNode] = None):
+    streams: list[str]
+    condition: ASTNode | None = None
+
+    def __init__(self, streams: list[str], line: int, column: int,
+                 condition: ASTNode | None = None):
         super().__init__(NodeType.SYNCHRONIZE, line, column)
         self.streams = streams
         self.condition = condition
 
 
 # Backwards compatibility aliases
-QuantumRunNode = RunNode  # For legacy code
\ No newline at end of file
+QuantumRunNode = RunNode  # For legacy code
