@@ -1,30 +1,28 @@
 """Complete JIT compiler implementation for Synapse language."""
 
 import ast as python_ast
-import sys
-import types
-import numba
-from numba import jit, njit, vectorize, cuda
-from numba.core import types as nb_types
-from numba.typed import Dict, List
-import numpy as np
-from typing import Any, Dict as PyDict, List as PyList, Optional, Callable, Union
-from dataclasses import dataclass
 import functools
 import hashlib
-import pickle
+import types
+from collections.abc import Callable
+from dataclasses import dataclass
+
+import numba
+import numpy as np
+from numba import cuda, jit, njit, vectorize
+
 from .ast_consolidated import *
 
 
 @dataclass
 class CompilationConfig:
     """JIT compilation configuration."""
-    backend: str = 'cpu'  # 'cpu', 'cuda', 'roc'
+    backend: str = "cpu"  # 'cpu', 'cuda', 'roc'
     parallel: bool = True
     fastmath: bool = True
     cache: bool = True
     nogil: bool = True
-    inline: str = 'always'
+    inline: str = "always"
     boundscheck: bool = False
     optimize_level: int = 3
     vector_width: int = 8
@@ -32,90 +30,90 @@ class CompilationConfig:
 
 class ASTTranspiler:
     """Transpiles Synapse AST to Python AST for JIT compilation."""
-    
+
     def __init__(self, config: CompilationConfig = None):
         self.config = config or CompilationConfig()
         self.symbol_table = {}
         self.temp_counter = 0
         self.loop_depth = 0
-    
+
     def transpile(self, node: ASTNode) -> python_ast.AST:
         """Transpile Synapse AST node to Python AST."""
-        method_name = f'transpile_{node.__class__.__name__}'
+        method_name = f"transpile_{node.__class__.__name__}"
         method = getattr(self, method_name, self.transpile_generic)
         return method(node)
-    
+
     def transpile_ProgramNode(self, node: ProgramNode) -> python_ast.Module:
         """Transpile program node."""
         body = [self.transpile(stmt) for stmt in node.statements]
         return python_ast.Module(body=body, type_ignores=[])
-    
+
     def transpile_NumberNode(self, node: NumberNode) -> python_ast.Constant:
         """Transpile number literal."""
         return python_ast.Constant(value=node.value)
-    
+
     def transpile_StringNode(self, node: StringNode) -> python_ast.Constant:
         """Transpile string literal."""
         return python_ast.Constant(value=node.value)
-    
+
     def transpile_IdentifierNode(self, node: IdentifierNode) -> python_ast.Name:
         """Transpile identifier."""
         return python_ast.Name(id=node.name, ctx=python_ast.Load())
-    
+
     def transpile_UncertainNode(self, node: UncertainNode) -> python_ast.Call:
         """Transpile uncertain value."""
         # Create uncertainty object
         return python_ast.Call(
-            func=python_ast.Name(id='UncertainValue', ctx=python_ast.Load()),
+            func=python_ast.Name(id="UncertainValue", ctx=python_ast.Load()),
             args=[
                 python_ast.Constant(value=node.value),
                 python_ast.Constant(value=node.uncertainty)
             ],
             keywords=[]
         )
-    
+
     def transpile_BinaryOpNode(self, node: BinaryOpNode) -> python_ast.AST:
         """Transpile binary operation."""
         left = self.transpile(node.left)
-        
+
         # Handle ternary operator specially
-        if node.operator == '?:':
+        if node.operator == "?:":
             return python_ast.IfExp(
                 test=left,
                 body=self.transpile(node.right[0]),
                 orelse=self.transpile(node.right[1])
             )
-        
+
         right = self.transpile(node.right)
-        
+
         # Map operators
         op_map = {
-            '+': python_ast.Add(),
-            '-': python_ast.Sub(),
-            '*': python_ast.Mult(),
-            '/': python_ast.Div(),
-            '//': python_ast.FloorDiv(),
-            '%': python_ast.Mod(),
-            '**': python_ast.Pow(),
-            '<<': python_ast.LShift(),
-            '>>': python_ast.RShift(),
-            '|': python_ast.BitOr(),
-            '^': python_ast.BitXor(),
-            '&': python_ast.BitAnd(),
-            '||': python_ast.Or(),
-            '&&': python_ast.And(),
-            '==': python_ast.Eq(),
-            '!=': python_ast.NotEq(),
-            '<': python_ast.Lt(),
-            '<=': python_ast.LtE(),
-            '>': python_ast.Gt(),
-            '>=': python_ast.GtE(),
+            "+": python_ast.Add(),
+            "-": python_ast.Sub(),
+            "*": python_ast.Mult(),
+            "/": python_ast.Div(),
+            "//": python_ast.FloorDiv(),
+            "%": python_ast.Mod(),
+            "**": python_ast.Pow(),
+            "<<": python_ast.LShift(),
+            ">>": python_ast.RShift(),
+            "|": python_ast.BitOr(),
+            "^": python_ast.BitXor(),
+            "&": python_ast.BitAnd(),
+            "||": python_ast.Or(),
+            "&&": python_ast.And(),
+            "==": python_ast.Eq(),
+            "!=": python_ast.NotEq(),
+            "<": python_ast.Lt(),
+            "<=": python_ast.LtE(),
+            ">": python_ast.Gt(),
+            ">=": python_ast.GtE(),
         }
-        
+
         if node.operator in op_map:
-            if node.operator in {'||', '&&'}:
+            if node.operator in {"||", "&&"}:
                 return python_ast.BoolOp(op=op_map[node.operator], values=[left, right])
-            elif node.operator in {'==', '!=', '<', '<=', '>', '>='}:
+            elif node.operator in {"==", "!=", "<", "<=", ">", ">="}:
                 return python_ast.Compare(
                     left=left,
                     ops=[op_map[node.operator]],
@@ -123,16 +121,16 @@ class ASTTranspiler:
                 )
             else:
                 return python_ast.BinOp(left=left, op=op_map[node.operator], right=right)
-        
+
         # Special operators
-        elif node.operator == '.':
+        elif node.operator == ".":
             # Member access
             return python_ast.Attribute(
                 value=left,
                 attr=right.id if isinstance(right, python_ast.Name) else str(right),
                 ctx=python_ast.Load()
             )
-        elif node.operator == '[]':
+        elif node.operator == "[]":
             # Indexing
             return python_ast.Subscript(
                 value=left,
@@ -141,95 +139,94 @@ class ASTTranspiler:
             )
         else:
             raise ValueError(f"Unknown operator: {node.operator}")
-    
+
     def transpile_UnaryOpNode(self, node: UnaryOpNode) -> python_ast.UnaryOp:
         """Transpile unary operation."""
         op_map = {
-            '-': python_ast.USub(),
-            '+': python_ast.UAdd(),
-            '!': python_ast.Not(),
-            'not': python_ast.Not(),
-            '~': python_ast.Invert(),
+            "-": python_ast.USub(),
+            "+": python_ast.UAdd(),
+            "!": python_ast.Not(),
+            "not": python_ast.Not(),
+            "~": python_ast.Invert(),
         }
-        
+
         operand = self.transpile(node.operand)
         op = op_map.get(node.operator)
-        
+
         if not op:
             raise ValueError(f"Unknown unary operator: {node.operator}")
-        
+
         return python_ast.UnaryOp(op=op, operand=operand)
-    
+
     def transpile_AssignmentNode(self, node: AssignmentNode) -> python_ast.Assign:
         """Transpile assignment."""
         target = python_ast.Name(id=node.target, ctx=python_ast.Store())
         value = self.transpile(node.value)
-        
+
         # Add to symbol table
         self.symbol_table[node.target] = {
-            'type': 'variable',
-            'uncertain': node.is_uncertain,
-            'constrained': node.is_constrained,
-            'evolving': node.is_evolving
+            "type": "variable",
+            "uncertain": node.is_uncertain,
+            "constrained": node.is_constrained,
+            "evolving": node.is_evolving
         }
-        
+
         return python_ast.Assign(targets=[target], value=value)
-    
+
     def transpile_FunctionCallNode(self, node: FunctionCallNode) -> python_ast.Call:
         """Transpile function call."""
         if isinstance(node.function, str):
             func = python_ast.Name(id=node.function, ctx=python_ast.Load())
         else:
             func = self.transpile(node.function)
-        
+
         args = [self.transpile(arg) for arg in node.arguments]
-        
+
         return python_ast.Call(func=func, args=args, keywords=[])
-    
+
     def transpile_ListNode(self, node: ListNode) -> python_ast.List:
         """Transpile list literal."""
         elements = [self.transpile(elem) for elem in node.elements]
         return python_ast.List(elts=elements, ctx=python_ast.Load())
-    
+
     def transpile_MatrixNode(self, node: MatrixNode) -> python_ast.Call:
         """Transpile matrix to numpy array."""
         rows = []
         for row in node.rows:
             row_elements = [self.transpile(elem) for elem in row]
             rows.append(python_ast.List(elts=row_elements, ctx=python_ast.Load()))
-        
+
         matrix_list = python_ast.List(elts=rows, ctx=python_ast.Load())
-        
+
         return python_ast.Call(
             func=python_ast.Attribute(
-                value=python_ast.Name(id='np', ctx=python_ast.Load()),
-                attr='array',
+                value=python_ast.Name(id="np", ctx=python_ast.Load()),
+                attr="array",
                 ctx=python_ast.Load()
             ),
             args=[matrix_list],
             keywords=[]
         )
-    
-    def transpile_BlockNode(self, node: BlockNode) -> PyList[python_ast.AST]:
+
+    def transpile_BlockNode(self, node: BlockNode) -> list[python_ast.AST]:
         """Transpile block of statements."""
         return [self.transpile(stmt) for stmt in node.statements]
-    
+
     def transpile_ParallelNode(self, node: ParallelNode) -> python_ast.AST:
         """Transpile parallel execution block."""
         # Generate parallel execution using numba.prange
-        temp_var = f'_parallel_{self.temp_counter}'
         self.temp_counter += 1
-        
+
         # Create function for parallel execution
-        func_name = f'_parallel_func_{self.temp_counter}'
+        func_name = f"_parallel_func_{self.temp_counter}"
         self.temp_counter += 1
-        
+
         # Build function body
         body = []
-        for i, branch in enumerate(node.branches):
+        for _i, branch in enumerate(node.branches):
             branch_stmts = self.transpile(branch.body) if isinstance(branch.body, list) else [self.transpile(branch.body)]
             body.extend(branch_stmts)
-        
+
         # Create parallel function
         parallel_func = python_ast.FunctionDef(
             name=func_name,
@@ -242,62 +239,62 @@ class ASTTranspiler:
             ),
             body=body or [python_ast.Pass()],
             decorator_list=[
-                python_ast.Name(id='njit', ctx=python_ast.Load()),
-                python_ast.Name(id='parallel', ctx=python_ast.Load())
+                python_ast.Name(id="njit", ctx=python_ast.Load()),
+                python_ast.Name(id="parallel", ctx=python_ast.Load())
             ]
         )
-        
+
         # Call the parallel function
         call = python_ast.Call(
             func=python_ast.Name(id=func_name, ctx=python_ast.Load()),
             args=[],
             keywords=[]
         )
-        
+
         return python_ast.Module(body=[parallel_func, python_ast.Expr(value=call)], type_ignores=[])
-    
+
     def transpile_IfNode(self, node: IfNode) -> python_ast.If:
         """Transpile if statement."""
         test = self.transpile(node.condition)
         body = self.transpile(node.then_branch) if isinstance(node.then_branch, list) else [self.transpile(node.then_branch)]
         orelse = []
-        
+
         if node.else_branch:
             orelse = self.transpile(node.else_branch) if isinstance(node.else_branch, list) else [self.transpile(node.else_branch)]
-        
+
         return python_ast.If(test=test, body=body, orelse=orelse)
-    
+
     def transpile_WhileNode(self, node: WhileNode) -> python_ast.While:
         """Transpile while loop."""
         self.loop_depth += 1
-        
+
         test = self.transpile(node.condition)
         body = self.transpile(node.body) if isinstance(node.body, list) else [self.transpile(node.body)]
-        
+
         self.loop_depth -= 1
-        
+
         return python_ast.While(test=test, body=body, orelse=[])
-    
+
     def transpile_ForNode(self, node: ForNode) -> python_ast.For:
         """Transpile for loop."""
         self.loop_depth += 1
-        
+
         target = python_ast.Name(id=node.variable, ctx=python_ast.Store())
         iter_expr = self.transpile(node.iterable)
         body = self.transpile(node.body) if isinstance(node.body, list) else [self.transpile(node.body)]
-        
+
         # Use numba.prange for parallel loops if in parallel context
         if self.config.parallel and self.loop_depth == 1:
             iter_expr = python_ast.Call(
-                func=python_ast.Name(id='prange', ctx=python_ast.Load()),
+                func=python_ast.Name(id="prange", ctx=python_ast.Load()),
                 args=[iter_expr] if isinstance(iter_expr, python_ast.Call) else [iter_expr],
                 keywords=[]
             )
-        
+
         self.loop_depth -= 1
-        
+
         return python_ast.For(target=target, iter=iter_expr, body=body, orelse=[])
-    
+
     def transpile_TensorNode(self, node: TensorNode) -> python_ast.AST:
         """Transpile tensor declaration."""
         # Create tensor with dimensions
@@ -305,13 +302,13 @@ class ASTTranspiler:
             elts=[python_ast.Constant(value=d) for d in node.dimensions],
             ctx=python_ast.Load()
         )
-        
+
         if node.initializer:
             init_value = self.transpile(node.initializer)
             tensor_call = python_ast.Call(
                 func=python_ast.Attribute(
-                    value=python_ast.Name(id='np', ctx=python_ast.Load()),
-                    attr='full',
+                    value=python_ast.Name(id="np", ctx=python_ast.Load()),
+                    attr="full",
                     ctx=python_ast.Load()
                 ),
                 args=[shape, init_value],
@@ -320,19 +317,19 @@ class ASTTranspiler:
         else:
             tensor_call = python_ast.Call(
                 func=python_ast.Attribute(
-                    value=python_ast.Name(id='np', ctx=python_ast.Load()),
-                    attr='zeros',
+                    value=python_ast.Name(id="np", ctx=python_ast.Load()),
+                    attr="zeros",
                     ctx=python_ast.Load()
                 ),
                 args=[shape],
                 keywords=[]
             )
-        
+
         return python_ast.Assign(
             targets=[python_ast.Name(id=node.name, ctx=python_ast.Store())],
             value=tensor_call
         )
-    
+
     def transpile_generic(self, node: ASTNode) -> python_ast.AST:
         """Generic transpilation for unhandled nodes."""
         # Return a pass statement for now
@@ -341,199 +338,198 @@ class ASTTranspiler:
 
 class JITCompiler:
     """JIT compiler for Synapse language."""
-    
+
     def __init__(self, config: CompilationConfig = None):
         self.config = config or CompilationConfig()
         self.transpiler = ASTTranspiler(config)
         self.compiled_cache = {}
         self.function_cache = {}
-    
+
     def compile_ast(self, ast_node: ASTNode, name: str = None) -> Callable:
         """Compile Synapse AST to optimized machine code."""
         # Generate cache key
         cache_key = self._get_cache_key(ast_node)
-        
+
         # Check cache
         if cache_key in self.compiled_cache:
             return self.compiled_cache[cache_key]
-        
+
         # Transpile to Python AST
         py_ast = self.transpiler.transpile(ast_node)
-        
+
         # Fix missing locations
         python_ast.fix_missing_locations(py_ast)
-        
+
         # Compile to Python bytecode
-        code = compile(py_ast, name or '<synapse_jit>', 'exec')
-        
+        code = compile(py_ast, name or "<synapse_jit>", "exec")
+
         # Create function from code
         func = self._create_function(code, name)
-        
+
         # Apply JIT compilation
         jit_func = self._apply_jit(func)
-        
+
         # Cache compiled function
         self.compiled_cache[cache_key] = jit_func
-        
+
         return jit_func
-    
+
     def _get_cache_key(self, ast_node: ASTNode) -> str:
         """Generate cache key for AST node."""
         # Serialize AST to string for hashing
         ast_str = str(ast_node)
         return hashlib.sha256(ast_str.encode()).hexdigest()
-    
+
     def _create_function(self, code: types.CodeType, name: str = None) -> Callable:
         """Create function from compiled code."""
         # Create namespace with required imports
         namespace = {
-            'np': np,
-            'numba': numba,
-            'njit': njit,
-            'jit': jit,
-            'prange': numba.prange,
-            'parallel': lambda f: f,  # Placeholder
-            'UncertainValue': UncertainValue,
-            '__builtins__': __builtins__,
+            "np": np,
+            "numba": numba,
+            "njit": njit,
+            "jit": jit,
+            "prange": numba.prange,
+            "parallel": lambda f: f,  # Placeholder
+            "UncertainValue": UncertainValue,
+            "__builtins__": __builtins__,
         }
-        
+
         # Execute code to define function
         exec(code, namespace)
-        
+
         # Find the main function
-        func_name = name or 'main'
+        func_name = name or "main"
         if func_name in namespace:
             return namespace[func_name]
-        
+
         # Return a wrapper that executes all code
         def wrapper(*args, **kwargs):
             local_ns = namespace.copy()
-            local_ns.update({'args': args, 'kwargs': kwargs})
+            local_ns.update({"args": args, "kwargs": kwargs})
             exec(code, local_ns)
-            return local_ns.get('__result__', None)
-        
+            return local_ns.get("__result__", None)
+
         return wrapper
-    
+
     def _apply_jit(self, func: Callable) -> Callable:
         """Apply JIT compilation based on configuration."""
         # Determine compilation options
         jit_options = {
-            'nopython': True,
-            'parallel': self.config.parallel,
-            'fastmath': self.config.fastmath,
-            'cache': self.config.cache,
-            'nogil': self.config.nogil,
+            "nopython": True,
+            "parallel": self.config.parallel,
+            "fastmath": self.config.fastmath,
+            "cache": self.config.cache,
+            "nogil": self.config.nogil,
         }
-        
+
         # Apply backend-specific compilation
-        if self.config.backend == 'cuda' and cuda.is_available():
+        if self.config.backend == "cuda" and cuda.is_available():
             return cuda.jit(func)
-        elif self.config.backend == 'cpu':
+        elif self.config.backend == "cpu":
             return njit(**jit_options)(func)
         else:
             # Fallback to regular JIT
             return jit(**jit_options)(func)
-    
-    def compile_function(self, func_ast: ASTNode, signature: Optional[str] = None) -> Callable:
+
+    def compile_function(self, func_ast: ASTNode, signature: str | None = None) -> Callable:
         """Compile a function with optional type signature."""
         # Extract function name and parameters
         if isinstance(func_ast, FunctionCallNode):
             func_name = func_ast.function
         else:
-            func_name = 'anonymous'
-        
+            func_name = "anonymous"
+
         # Check function cache
         cache_key = f"{func_name}_{signature}"
         if cache_key in self.function_cache:
             return self.function_cache[cache_key]
-        
+
         # Compile function
         compiled = self.compile_ast(func_ast, func_name)
-        
+
         # Apply type signature if provided
         if signature:
             compiled = self._apply_signature(compiled, signature)
-        
+
         # Cache compiled function
         self.function_cache[cache_key] = compiled
-        
+
         return compiled
-    
+
     def _apply_signature(self, func: Callable, signature: str) -> Callable:
         """Apply Numba type signature to function."""
         # Parse signature string (e.g., "float64(float64, float64)")
         try:
             # Use numba's signature parsing
-            from numba.core.typing.typeof import typeof
             return njit(signature)(func)
         except Exception:
             # Fallback to no signature
             return func
-    
+
     def compile_parallel(self, ast_node: ParallelNode) -> Callable:
         """Compile parallel execution block."""
         # Force parallel compilation
         old_parallel = self.config.parallel
         self.config.parallel = True
-        
+
         try:
             compiled = self.compile_ast(ast_node)
             return compiled
         finally:
             self.config.parallel = old_parallel
-    
+
     def compile_quantum(self, circuit_ast: QuantumCircuitNode) -> Callable:
         """Compile quantum circuit for simulation."""
         # Quantum circuits require special handling
-        def quantum_executor(backend='simulator'):
+        def quantum_executor(backend="simulator"):
             from .quantum.simulator import QuantumSimulator
-            
+
             sim = QuantumSimulator(circuit_ast.qubits)
-            
+
             # Apply gates
             for gate in circuit_ast.gates:
                 gate_type = gate.gate_type.lower()
-                qubits = [int(q.value) if hasattr(q, 'value') else 0 
+                qubits = [int(q.value) if hasattr(q, "value") else 0
                          for q in gate.qubits]
-                params = [float(p.value) if hasattr(p, 'value') else 0.0 
+                params = [float(p.value) if hasattr(p, "value") else 0.0
                          for p in gate.parameters]
-                
-                if gate_type == 'h':
+
+                if gate_type == "h":
                     sim.h(qubits[0])
-                elif gate_type == 'x':
+                elif gate_type == "x":
                     sim.x(qubits[0])
-                elif gate_type == 'y':
+                elif gate_type == "y":
                     sim.y(qubits[0])
-                elif gate_type == 'z':
+                elif gate_type == "z":
                     sim.z(qubits[0])
-                elif gate_type in ['cnot', 'cx']:
+                elif gate_type in ["cnot", "cx"]:
                     sim.cnot(qubits[0], qubits[1])
-                elif gate_type == 'rx':
+                elif gate_type == "rx":
                     sim.rx(qubits[0], params[0])
-                elif gate_type == 'ry':
+                elif gate_type == "ry":
                     sim.ry(qubits[0], params[0])
-                elif gate_type == 'rz':
+                elif gate_type == "rz":
                     sim.rz(qubits[0], params[0])
-            
+
             # Perform measurements
             results = {}
             for measure in circuit_ast.measurements:
                 for qubit in measure.qubits:
-                    q_idx = int(qubit.value) if hasattr(qubit, 'value') else 0
-                    results[f'q{q_idx}'] = sim.measure(q_idx)
-            
+                    q_idx = int(qubit.value) if hasattr(qubit, "value") else 0
+                    results[f"q{q_idx}"] = sim.measure(q_idx)
+
             return results
-        
+
         return quantum_executor
 
 
 class UncertainValue:
     """Runtime representation of uncertain values."""
-    
+
     def __init__(self, value: float, uncertainty: float):
         self.value = value
         self.uncertainty = uncertainty
-    
+
     def __add__(self, other):
         if isinstance(other, UncertainValue):
             # Add uncertainties in quadrature
@@ -542,7 +538,7 @@ class UncertainValue:
             return UncertainValue(new_value, new_uncertainty)
         else:
             return UncertainValue(self.value + other, self.uncertainty)
-    
+
     def __mul__(self, other):
         if isinstance(other, UncertainValue):
             new_value = self.value * other.value
@@ -553,51 +549,51 @@ class UncertainValue:
             return UncertainValue(new_value, new_uncertainty)
         else:
             return UncertainValue(self.value * other, abs(self.uncertainty * other))
-    
+
     def __repr__(self):
         return f"{self.value} ± {self.uncertainty}"
 
 
 class OptimizationPass:
     """Optimization pass for compiled code."""
-    
+
     def __init__(self, config: CompilationConfig):
         self.config = config
-    
+
     def optimize(self, func: Callable) -> Callable:
         """Apply optimization passes."""
         # Apply vectorization where possible
         if self.config.vector_width > 1:
             func = self._vectorize(func)
-        
+
         # Apply loop unrolling
         if self.config.optimize_level >= 2:
             func = self._unroll_loops(func)
-        
+
         # Apply constant folding
         if self.config.optimize_level >= 1:
             func = self._fold_constants(func)
-        
+
         return func
-    
+
     def _vectorize(self, func: Callable) -> Callable:
         """Vectorize function for SIMD execution."""
         try:
             # Attempt to vectorize with Numba
             return vectorize([
-                'float64(float64)',
-                'float32(float32)',
-                'int64(int64)',
-                'int32(int32)'
-            ], target='parallel')(func)
+                "float64(float64)",
+                "float32(float32)",
+                "int64(int64)",
+                "int32(int32)"
+            ], target="parallel")(func)
         except Exception:
             return func
-    
+
     def _unroll_loops(self, func: Callable) -> Callable:
         """Unroll small loops for better performance."""
         # This would require AST manipulation
         return func
-    
+
     def _fold_constants(self, func: Callable) -> Callable:
         """Fold constant expressions at compile time."""
         # This would require AST manipulation
@@ -608,56 +604,56 @@ class OptimizationPass:
 def synapse_jit(config: CompilationConfig = None):
     """Decorator for JIT compiling Synapse functions."""
     def decorator(func):
-        compiler = JITCompiler(config)
-        
+        JITCompiler(config)
+
         @functools.wraps(func)
         def wrapper(*args, **kwargs):
             # Get function AST (would need parser integration)
             # For now, just apply Numba JIT
             jit_func = njit(func)
             return jit_func(*args, **kwargs)
-        
+
         return wrapper
-    
+
     return decorator
 
 
 # Utility functions
 def compile_synapse_code(code: str, config: CompilationConfig = None) -> Callable:
     """Compile Synapse code string to optimized function."""
-    from .synapse_lexer import Lexer
     from .parser_enhanced import EnhancedParser
-    
+    from .synapse_lexer import Lexer
+
     # Parse code
     lexer = Lexer(code)
     tokens = lexer.tokenize()
     parser = EnhancedParser(tokens)
     ast = parser.parse()
-    
+
     # Compile AST
     compiler = JITCompiler(config)
     return compiler.compile_ast(ast)
 
 
-def benchmark_compilation(code: str, iterations: int = 1000) -> PyDict[str, float]:
+def benchmark_compilation(code: str, iterations: int = 1000) -> dict[str, float]:
     """Benchmark JIT compilation vs interpretation."""
     import time
-    
+
     # Compile code
     compiled = compile_synapse_code(code)
-    
+
     # Benchmark compiled version
     start = time.perf_counter()
     for _ in range(iterations):
         compiled()
     compiled_time = time.perf_counter() - start
-    
+
     # Would need interpreter for comparison
     interpreted_time = compiled_time * 10  # Placeholder
-    
+
     return {
-        'compiled_time': compiled_time,
-        'interpreted_time': interpreted_time,
-        'speedup': interpreted_time / compiled_time,
-        'iterations': iterations
-    }
\ No newline at end of file
+        "compiled_time": compiled_time,
+        "interpreted_time": interpreted_time,
+        "speedup": interpreted_time / compiled_time,
+        "iterations": iterations
+    }
