@@ -4,10 +4,8 @@ Phase 1, Week 1, Day 1-2
 Implements complete parsing for all language constructs
 """
 
-import sys
-from typing import List, Optional, Dict, Any, Union
-from synapse_lang.synapse_lexer import Lexer, Token, TokenType
 from synapse_lang.synapse_ast_enhanced import *
+from synapse_lang.synapse_lexer import Lexer, Token, TokenType
 
 
 class ParserError(Exception):
@@ -46,7 +44,7 @@ class EnhancedParser:
 
     # ========== Statement Parsing ==========
 
-    def parse_statement(self) -> Optional[ASTNode]:
+    def parse_statement(self) -> ASTNode | None:
         """Parse a single statement"""
         # Skip newlines
         while self.match(TokenType.NEWLINE):
@@ -1134,7 +1132,7 @@ class EnhancedParser:
 
         return BlockNode(statements, self.previous().line, self.previous().column)
 
-    def parse_expression_list(self) -> List[ASTNode]:
+    def parse_expression_list(self) -> list[ASTNode]:
         """Parse comma-separated expression list"""
         expressions = []
 
@@ -1175,7 +1173,7 @@ class EnhancedParser:
         """Return current token without consuming"""
         return self.tokens[self.current]
 
-    def peek_next(self) -> Optional[Token]:
+    def peek_next(self) -> Token | None:
         """Return next token without consuming"""
         if self.current + 1 < len(self.tokens):
             return self.tokens[self.current + 1]
@@ -1218,4 +1216,4 @@ class EnhancedParser:
 
 
 # Export enhanced parser as default
-Parser = EnhancedParser
\ No newline at end of file
+Parser = EnhancedParser
